elephant.pandas\_bridge.multi\_spiketrains\_to\_dataframe
=========================================================

.. currentmodule:: elephant.pandas_bridge

.. autofunction:: multi_spiketrains_to_dataframe